import * as prompts from "@clack/prompts";
import { doesRepositoryExist } from "./doesRepositoryExist.js";
import { handleCancel, handlePromptCancel } from "./prompts.js";
async function ensureRepositoryExists(octokit, values) {
  let { createRepository, repository } = values;
  while (octokit) {
    if (await doesRepositoryExist(octokit, values)) {
      return { octokit, repository };
    }
    const selection = createRepository ? "create" : await prompts.select({
      message: `Repository ${values.repository} doesn't seem to exist under ${values.owner}. What would you like to do?`,
      options: [
        { label: "Create a new repository", value: "create" },
        {
          label: "Switch to a different repository name",
          value: "different"
        },
        {
          label: "Keep changes local",
          value: "local"
        },
        { label: "Bail out and maybe try again later", value: "bail" }
      ]
    });
    createRepository = false;
    handlePromptCancel(selection);
    switch (selection) {
      case "bail":
        handleCancel();
        break;
      case "create":
        await octokit.rest.repos.createUsingTemplate({
          name: repository,
          owner: values.owner,
          template_owner: "JoshuaKGoldberg",
          template_repo: "template-typescript-node-package"
        });
        return { octokit, repository };
      case "different":
        const newRepository = await prompts.text({
          message: `What would you like to call the repository?`
        });
        handlePromptCancel(newRepository);
        repository = newRepository;
        break;
      case "local":
        octokit = void 0;
        break;
    }
  }
  return { octokit, repository };
}
export {
  ensureRepositoryExists
};
//# sourceMappingURL=ensureRepositoryExists.js.map